---
title: CloseOverlay
description: JSON Schema for the CloseOverlay action.
---

Close the nearest ancestor overlay (Dialog or Popover).

```json
{
  "type": "object",
  "properties": {
    "action": {
      "const": "closeOverlay",
      "default": "closeOverlay",
      "type": "string"
    }
  },
  "required": [
    "action"
  ]
}
```
